// ============
// ANDRAO-HTTPS
// ============

'use strict';

const http = require('http'),
    https = require('https'),
    log = require('andrao-logger')('ANDRAO-HTTPS'),
    chalk = require('chalk'),
    redirectHTTPS = require('redirect-https')

const greenlock = require('greenlock-express');


module.exports = function(app, opts_in){
    
    const options = Object.assign({
        http_port: 80,
        https_port: 443,
        domains: ['example.com'],
        staging: true,
        config_dir: `~/.config/acme`,
        email: 'john.doe@example.com',
        redirect: false
    }, opts_in)

    const glock = greenlock.create({

        // Let's Encrypt v2 is ACME draft 11
        version: 'draft-11',

        server: options.staging
            ? 'https://acme-staging-v02.api.letsencrypt.org/directory'
            : 'https://acme-v02.api.letsencrypt.org/directory',


        // Where the certs will be saved, MUST have write access
        configDir: options.config_dir,

        email: options.email,

        approveDomains: options.domains,

        // You MUST NOT build clients that accept the ToS without asking the user
        agreeTos: true,

        app: app,

        // Join the community to get notified of important updates
        communityMember: !!options.communityMember,

        // Contribute telemetry data to the project
        telemetry: !!options.telemetry,

        debug: !!options.debug

    });



    // Set up servers
    const servers = { http:[], https:[] };


    if(options.http_port){
        servers.http.push(http.createServer(glock.middleware(redirectHTTPS())).listen(options.http_port, function () {
            console.log("Listening for ACME http-01 challenges on", this.address());
        }));
    }

    if(options.https_port){
        servers.https.push(https.createServer(glock.httpsOptions, app).listen(options.https_port, function (){
            console.log("Listening for ACME tls-sni-01 challenges and serve app on", this.address());
        }));
    }

    return servers;
};